module vga_sync(clock_25Mhz, red_in, green_in, blue_in, 
	red_out, green_out, blue_out, horiz_sync, vertical_sync, pixel_row, pixel_column);
input clock_25Mhz, red_in, green_in, blue_in;
output red_out, green_out, blue_out, horiz_sync, vertical_sync;
output [9:0] pixel_row, pixel_column;
reg [9:0] pixel_row, pixel_column;
wire video_on;
reg video_on_v, video_on_h;
reg red_out, green_out, blue_out, horiz_sync, vertical_sync;
reg [9:0] h_count, v_count;

// video_on is high only when RGB data is displayed
assign video_on = video_on_h & video_on_v;

always @ (posedge clock_25Mhz) 
begin
/* Generate Horizontal and Vertical Timing Signals for Video Signal
* h_count counts pixels (640 + extra time for sync signals)
* 
*  horiz_sync  ------------------------------------__________--------
*  h_count       0                640             659       755    799
*/
if (h_count == 799) h_count <= 10'b0000000000;
else h_count <= h_count + 1;

// Generate Horizontal Sync Signal using h_count

if (h_count <= 755 && h_count >= 659) horiz_sync <= 1'b0;
else horiz_sync <= 1'b1;


/* v_count counts rows of pixels (480 + extra time for sync signals)
*  
*  vertical_sync      -----------------------------------------------_______------------
*  v_count             0                                      480    493-494          524
*/
	if (v_count >= 524 && h_count >= 699) v_count <= 10'b0000000000;
	else if (h_count == 699) v_count <= v_count + 1;

// Generate Vertical Sync Signal using v_count
	if (v_count <= 494 && v_count >= 493) vertical_sync <= 1'b0;
	else vertical_sync <= 1'b1;

// Generate Video on Screen Signals for Pixel Data
	if (h_count <= 639) begin
   		video_on_h <= 1'b1;
   		pixel_column <= h_count;
	end
	else video_on_h <= 1'b0;

	if (v_count <= 479) begin
   		video_on_v <= 1'b1;
   		pixel_row <= v_count;
	end
	else video_on_v <= 1'b0;


// Put all video signals through DFFs to elminate any delays that cause a blurry image
		red_out <= red_in & video_on;
		green_out <= green_in & video_on;
		blue_out <= blue_in & video_on;
end
endmodule

